#!/bin/sh

## Installation script for the FIMS tool

UNPACK_DIR=`pwd`

if [ ! -f "$UNPACK_DIR/fims_install.sh" ] ; then
    echo "Please run this installation script from inside the package"
    echo "directory (cd <some_path>/fims-P74-LinuxRH9/)"
    exit;
fi

## Welcome banner and warning
echo "** Welcome to the FIMS installation script **\n"

echo "======================================================"
echo "PLEASE NOTE: this package is to be used for period 74"
echo "of observations for the ESO telescopes. The Finding"
echo "Chart plug-in included in this package may be used for"
echo "any service mode program. The FIMS tool in this"
echo "package is dedicated to programs for FORS1 and FORS2."
echo "======================================================\n"

## General variables
FORS_PACKAGE=fims-2.44-P74.tar.gz
FCPLUGIN_PACKAGE=skycatFCPlugin-P74.tar.gz

## Choice of installation directory

echo "1) Installation directory:"
echo "--------------------------"

INSTALL_PATH=$UNPACK_DIR

echo "Where do you want to install the FIMS package ? The default is"
echo "the current directory."

repeatStep=1

while [ $repeatStep -eq 1 ]
do
    echo "Please enter the installation directory [" $INSTALL_PATH "] :"

    read answer

    test $answer
    if [ $? -ne 0 ] ; then
	repeatStep=0
    else

	GREP=`echo $answer | grep "^/"`

	if [ $? -ne 0 ] ; then

	    echo "Please enter an absolute path (starting with / )."

	elif [ ! -d $answer ] ; then

	    echo $answer "does not appear to exist. Do you want to create it ? [y]"
	    read makedir
	    test $makedir
	    if [ $? -ne 0 ] ; then
		makedir=y
	    fi

	    if [ $makedir = "y" ] ; then
		mkdir -p $answer 2>/dev/null
		if [ $? -ne 0 ] ; then
		    echo "Cannot create this directory ! Please choose another one...\n"
		else
		    INSTALL_PATH=$answer
		    repeatStep=0
		fi
	    fi

	elif [ ! -w $answer ] ; then
	    echo "You do not appear to have write access to" $answer "."
	    echo "Please choose another directory for installation."
	else
	    INSTALL_PATH=$answer
	    repeatStep=0
	fi
    fi
done

echo "Installing FIMS package in "$INSTALL_PATH"\n"

## Locating the Perl executable

echo "2) Perl executable"
echo "------------------"
echo "The Perl interpreter is needed to produce Postscript files"
echo "for MXU masks (FORS2 programs)"

PERL_EXEC=perl

$PERL_EXEC -v > /dev/null

if [ $? -eq 0 ]; then
    PERL_PATH=`which $PERL_EXEC 2>/dev/null`
    echo "I found the Perl interpreter in the following location: " $PERL_PATH
else
    echo "Hmmm... I didn't find the Perl interpreter in your path."
    echo "You can either decide to specify the path to your Perl interpreter,"
    echo "or use FIMS without Perl (you won't be able to produce Postscript files for MXU masks)"
    echo "Would you like to specify the path for perl ? [y/n]"
    read answer
    if [ $answer = "y" ] ; then
	echo "Please enter the absolute path to the perl interpreter:"
	read PERL_PATH
	if [ $PERL_PATH ] ; then
	    echo "Using" $PERL_PATH "as the perl interpreter."
	else
	    echo "You will use FIMS without perl."
	    PERL_PATH=""
	fi
    else
	echo "You will use FIMS without perl."
	PERL_PATH=""
    fi
fi


echo
echo "3) Installing the FIMS package"
echo "------------------------------\n"

echo "Unpacking FIMS..."
gzip -d -c $FORS_PACKAGE | tar xvf - -C $INSTALL_PATH > /dev/null
echo "done.\n"

echo "Building FIMS..."
#FORS_DIR=`echo $FORS_PACKAGE | sed s/.tar.gz//`
cd $INSTALL_PATH/fims/src

test -n "$PERL_PATH"
if [ $? -eq 0 ] ; then

    echo "Updating the perl scripts..."
    chmod u+w gerber2ps.perl
    rm -f gerber2ps.perl.new
    cat gerber2ps.perl | awk '{ if(NR==1) printf("#!" A "\n"); else print $0 }' A=$PERL_PATH > gerber2ps.perl.new
    mv -f gerber2ps.perl.new gerber2ps.perl
    chmod u-w gerber2ps.perl

    chmod u+w gerber2eps.perl
    rm -f gerber2eps.perl.new
    cat gerber2eps.perl | awk '{ if(NR==1) printf("#!" A "\n"); else print $0 }' A=$PERL_PATH > gerber2eps.perl.new
    mv -f gerber2eps.perl.new gerber2eps.perl
    chmod u-w gerber2eps.perl
fi

make

cd $UNPACK_DIR

echo "done.\n"

echo "Unpacking Finding Chart plug-in..."
gzip -d -c $FCPLUGIN_PACKAGE | tar xvf - > /dev/null
echo "done.\n"

echo "Installing plug-in..."
FCPLUGIN_DIR=`echo $FCPLUGIN_PACKAGE | sed s/.tar.gz//`
cd $FCPLUGIN_DIR

PLUGIN_INSTALL_DIR=$INSTALL_PATH/lib/libfcPlugins.tcl
mkdir -p $PLUGIN_INSTALL_DIR
cp FindingChart_plugin.tcl  $PLUGIN_INSTALL_DIR/.
cp FC_tclIndex              $PLUGIN_INSTALL_DIR/tclIndex
chmod 755 $PLUGIN_INSTALL_DIR
chmod 644 $PLUGIN_INSTALL_DIR/*


echo "done."

echo "Installing scripts and binaries..."

BINDIR=$INSTALL_PATH/bin
mkdir -p $BINDIR

FIMSPATH=`echo $INSTALL_PATH | sed s/[/]/\\\\\\\\\\\\\\\\\\\\\\\\\\\//g`

sed -e s/@@FIMSBASEPATH@@/$FIMSPATH/ $UNPACK_DIR/fims.sh.tpl | sed s/\\\\//g > $BINDIR/fims.sh
chmod 755 $BINDIR/fims.sh

cp -pr $UNPACK_DIR/skycat.app $BINDIR/skycat.app
#chmod u+x $BINDIR/skycat
ln -s $BINDIR/skycat.app/Contents/Resources/bin/skycat $BINDIR/skycat

cp $UNPACK_DIR/fsmosaic $BINDIR/fsmosaic
chmod u+x $BINDIR/fsmosaic

echo "done."

echo "Cleaning up..."

if [ $UNPACK_DIR == $INSTALL_PATH ] ; then
    CLEANDIR=0
    cd $UNPACK_DIR
    rm -rf $FCPLUGIN_DIR
    rm -f $FORS_PACKAGE
    rm -f $FCPLUGIN_PACKAGE
    rm -f fims.sh.tpl
    rm -f skycat
    rm -f fsmosaic
    rm -f fims_install.sh
else
    CLEANDIR=1
    rm -rf $UNPACK_DIR/*
fi

echo "done"
echo

if [ $CLEANDIR -eq 1 ] ; then
    echo "(NB: you can remove the directory" $UNPACK_DIR ")\n"
fi

echo "** FIMS was built successfully **\n"

echo "The FIMS tool can be launched with the command"
echo $INSTALL_PATH"/bin/fims.sh [1|2]"
echo


